/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: AdamSelene
 */

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Rules.DependencyMap.View
{
    /// <summary>
    /// Unit test fixture for basic tests against the expected functionality of the component.
    /// These tests were created to help score the component on points such as meeting required
    /// functionality.
    /// </summary>
    [TestFixture]
    public class AdamSeleneUnitTests
    {
		/// <summary>
		/// Output target.
		/// </summary>
    	private string dir = @"../../test_files/failuretests/suppress";

        /// <summary>
        /// The shape factory to use for each test (more or less a place holder).
        /// </summary>
        private ShapeFactory factory = null;

        /// <summary>
        /// Set up shape factory for each test.
        /// </summary>
        [SetUp]
        protected void SetUp()
        {
            factory = new ShapeFactory();
        }

        /// <summary>
        /// Test RenderAll() with various input.  This test was repeated with varying input.
        /// </summary>
        [Test]
        public void RenderAllTrue()
        {
            IDiagramRenderer dr = new SVGRenderer(@"../../test_files/failuretests/renderAll");
            DependencyRenderer renderer = new DependencyRenderer(factory);

            renderer.AddDiagramRenderer(dr);
            //renderer.AddDiagramRenderer(dr2);
            
            Dependency a = new Dependency("a");
            Dependency b = new Dependency("b");
            Dependency c = new Dependency("c");
            Dependency d = new Dependency("d");
        
            b.AddDependant(d);
            c.AddDependant(d);
            a.AddDependant(b);
            a.AddDependant(c);
            
            renderer.RenderAll(a, true);

        }        
      
        /// <summary>
        /// Test RenderAll() with simple case. This test was repeated with varying input.
        /// </summary>
        [Test]
        public void RenderAll2()
        {
            IDiagramRenderer dr = new SVGRenderer(@"../../test_files/failuretests/suppress");
            DependencyRenderer renderer = new DependencyRenderer();

            renderer.AddDiagramRenderer(dr);
            
            Dependency a = new Dependency("a");
            Dependency b = new Dependency("i");
            Dependency c = new Dependency("g");
            Dependency d = new Dependency("d");
            Dependency e = new Dependency("e");
            Dependency f = new Dependency("f");
            Dependency g = new Dependency("h");
            Dependency h = new Dependency("c");
            Dependency i = new Dependency("b");
            Dependency j = new Dependency("j");
            Dependency k = new Dependency("k");
            Dependency l = new Dependency("l");
            Dependency m = new Dependency("m");
            Dependency n = new Dependency("n");
            Dependency o = new Dependency("o");
            Dependency p = new Dependency("p");
        
            m.AddDependant(n);
            m.AddDependant(o);
            m.AddDependant(p);

            c.AddDependant(d);
            c.AddDependant(e);

            b.AddDependant(c);
            b.AddDependant(f);
            b.AddDependant(g);
            b.AddDependant(h);

            i.AddDependant(j);
            i.AddDependant(k);
            i.AddDependant(l);
            i.AddDependant(m);

            a.AddDependant(b);
            a.AddDependant(i);

            renderer.RenderAll(a, true);
        }      
    
        /// <summary>
        /// Test RenderAll() for simple case. This test was repeated with varying input.
        /// </summary>
        [Test]
        public void RenderAll3()
        {
            IDiagramRenderer dr = new SVGRenderer(@"../../test_files/failuretests/suppress2");
            DependencyRenderer renderer = new DependencyRenderer();

            renderer.AddDiagramRenderer(dr);
            
            Dependency a = new Dependency("a");
            Dependency b = new Dependency("b");
            Dependency c = new Dependency("c");
            Dependency d = new Dependency("d");
            Dependency e = new Dependency("e");
            Dependency f = new Dependency("f");
            Dependency g = new Dependency("g");
            Dependency h = new Dependency("h");
            Dependency i = new Dependency("i");
            Dependency j = new Dependency("j");
            Dependency k = new Dependency("k");
 
            e.AddDependant(f);
            e.AddDependant(g);

            d.AddDependant(e);
            d.AddDependant(h);
            d.AddDependant(i);
            d.AddDependant(j);

            b.AddDependant(c);
            b.AddDependant(d);
            b.AddDependant(k);
            a.AddDependant(b);

            renderer.RenderAll(a, true);
        }    
    }

}
