/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Rules.DependencyMap.View
{   
    /// <summary>
    /// Failure test fixture for FGL.
    /// </summary>
    [TestFixture]
    public class FGLTests
    {
        Dependency goodDep = new Dependency("test");
        private IDiagramRenderer goodRenderer = new SVGRenderer(".");
        private ShapeFactory goodSF = new ShapeFactory();
    	
        /// <summary>
        /// Invalid input to constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon_Inv() 
        {
            new FixedGridLayoutManager(-1, 0);
        }
        
        /// <summary>
        /// Invalid input to constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon_Inv2() 
        {
            new FixedGridLayoutManager(-1, -1);

        }    
        	
        /// <summary>
        /// Invalid input to constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon_Inv3() 
        {
            new FixedGridLayoutManager(0, -1);
        }  
        	
        /// <summary>
        /// Invalid input to constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon_Inv4() 
        {
            new FixedGridLayoutManager(0, int.MinValue);
        }
        	
        /// <summary>
        /// Invalid input to constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon2_Inv() 
        {
            new FixedGridLayoutManager(-1, 0, 0);
        }
        	
        /// <summary>
        /// Invalid input to constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon2_Inv2() 
        {
            new FixedGridLayoutManager(-1, -1, 0);
        }    
        	
        /// <summary>
        /// Invalid dimension to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon2_Inv3() 
        {
            new FixedGridLayoutManager(0, -1, 0);
        }  
        	
        /// <summary>
        /// Invalid dimension to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon2_Inv4() 
        {
            new FixedGridLayoutManager(0, int.MinValue, 0);
        }
        	
        	
        /// <summary>
        /// Invalid (invalid type) input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon2_Inv5() 
        {
            
            new FixedGridLayoutManager(0, 0, -1);
        }
        	
        /// <summary>
        /// Valid input to Layout.  Should not throw any exception.
        /// </summary>
        [Test]
        public void testLayout_Silent() 
        {
            new FixedGridLayoutManager().Layout(goodDep, goodSF, goodRenderer);
        }

        	
        /// <summary>
        /// Invalid input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N1() 
        {
            new FixedGridLayoutManager().Layout(null, goodSF, goodRenderer);                      
        }

        /// <summary>
        /// Invalid input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N2() 
        {
            new FixedGridLayoutManager().Layout(goodDep, null, goodRenderer);
        }


        /// <summary>
        /// Invalid input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N3() 
        {
            new FixedGridLayoutManager().Layout(goodDep, goodSF, null);
        }

        /// <summary>
        /// Invalid input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N4() 
        {
            new FixedGridLayoutManager().Layout(null, null, goodRenderer);
        }

        /// <summary>
        /// Invalid (null) input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N5() 
        {
            new FixedGridLayoutManager().Layout(null, goodSF, null);
        }

        /// <summary>
        /// Invalid (null) input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N6() 
        {
            new FixedGridLayoutManager().Layout(goodDep, null, null);
        }

        /// <summary>
        /// Invalid (null) input to FGLM constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testLayout_N7() 
        {
            new FixedGridLayoutManager().Layout(null, null, null);
        }
    }
}
